@@ -9,6 +9,12 @@ has base_url => (
     is      => 'ro',
     default => sub { 'https://api.balancedpayments.com' }
 );
+has headers_v1_1 => (
+    is      => 'rw',
+    default => sub {
+        { accept       => 'application/vnd.api+json;revision=1.1' }
+    },
+);
 has ua => (
     is      => 'ro',
     lazy    => 1,
@@ -27,18 +33,28 @@ sub get {
     return $self->_req(GET $path);
 }
 
+sub get_v1_1 {
+    my ($self, $path) = @_;
+    return $self->_req_v1_1(GET $path);
+}
+
 sub post {
     my ($self, $path, $params) = @_;
     return $self->_req(POST $path, content => encode_json $params);
 }
 
+sub post_v1_1 {
+    my ($self, $path, $params) = @_;
+    return $self->_req_v1_1(POST $path, content => encode_json $params);
+}
+
 sub put {
     my ($self, $path, $params) = @_;
     return $self->_req(PUT $path, content => encode_json $params);
 }
 
 # Prefix the path param of the http methods with the base_url
-around qw(get post put) => sub {
+around qw(get get_v1_1 post post_v1_1 put) => sub {
     my $orig = shift;
     my $self = shift;
     my $path = shift;
@@ -69,6 +85,12 @@ sub _req {
     return $res->content ? decode_json($res->content) : 1;
 }
 
+sub _req_v1_1 {
+    my ($self, $req) = @_;
+    $req->header( %{ $self->headers_v1_1 } );
+    return $self->_req( $req );
+}
+
 sub _url {
     my ($self, $path) = @_;
     return $path =~ /^http/ ? $path : $self->base_url . $path;
@@ -105,7 +127,7 @@ Business::BalancedPayments::HTTP
 
 =head1 VERSION
 
-version 0.1300
+version 0.1500
 
 =head1 AUTHORS
 
